# Makefile for RUST-1.0b6pl2
#
# Copyright (C) 1996 Craig Ruefenacht <ruefenac@cs.utah.edu> and the
#                    University of Utah Computer Science Department
#
# $Id: Makefile.tpl,v 1.14 1997/09/20 19:43:16 ruefenac Exp $
#
# This is part of RUST-1.0 Beta 6 patchlevel 2
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with the source distribution of Inquire, in the license
# directory. If you don't have a copy of it, write to: 
#
# Free Software Foundation, Inc.
# 675 Mass Ave
# Cambridge, MA 02139, USA.

# Change these if needed...

# Install program
INSTALLPROGRAM=/usr/local/gnu/bin/install

# OS is the type of OS you are building for.  This is only
# important for the rust.c binary.  Its used to determine
# where to install the rust binary.  Whatever you make
# the OS var to be, it needs to be architecture dependant.
# Its used to install the binary to:
#
#           <rust_top_level>/bin/<OS>/rust
#
# Some suggestions are:
#      
#          sun4    (for SunOS 4.1.x)
#          sun53   (for Solaris 2.3)
#          sun54   (for Solaris 2.4 & 2.5)
#          hpux9   (for HP-UX 9.x & 10.x)
#          hp700bsd (for HP700 machines running BSD)
#          irix52  (for IRIX 5.2)
#          irix53  (for IRIX 5.3)
#          irix62  (For IRIX 6.2)
OS=sun4

# PERL should point to perl5.00x.  This is used only for installation
# purposes.  You also need to define where perl is in install/Rust_Install.pm
PERL=perl

# Any ansi C compiler will do, including gcc
CC = cc

# rm should be in /bin, but maybe you have it someplace else
RM = /bin/rm

# ln should be in /bin or /usr/bin, but maybe you have it somelace else
# Should do a symbolic link.
LN = /usr/bin/ln -s

DEFINES=
 
# DEFINES
#
# If compiling check-q (server_bins) for Solaris/Irix, uncomment
# the following DEFINES line
#
#DEFINES=-DTCP_2

# target dir and pseudo user/group for RUST Mail System files
INSTALLDIR=/home/assist/tests/test_rust_b6
PSEUDO_USER=rustsys
PSEUDO_GROUP=rustsys
USER_GROUP=rust

# Paths and TCP port assignments for the server/client.
#
# I suggest you put the check-q binary in /usr/local/bin
# or wherever you keep most architecture dependant binaryes.
# The LOCALBINDIR is the directory to where the check-q binary
# will be installed to.
#
SERVERDIR=/home/assist/tests/server
LOCALBINDIR=/home/assist/tests/bin/sun4
SERVERPORT=1910

# Shouldn't have to change anything below this line

nothing:
	@echo
	@echo "Makefile for RUST-1.0b6 patchlevel 2 (pl2)"
	@echo
	@echo "Read docs/INSTALL if you haven't already..."
	@echo 
	@echo "You can do the following commands with this Makefile"
	@echo
	@echo "    make rust           : Extract RUST source"
	@echo "    make rust_install   : Install RUST files"
	@echo "    make server         : Extract server source"
	@echo "    make server_install : Install server files 
	@echo 
	@echo "To make the rust binary on other architectures, log into the
	@echo "desired arch, edit the top level Makefile, and then issue the
	@echo "following commands from the top level directory as the RUST"
	@echo "pseudo user:"
	@echo
	@echo "       make bins"
	@echo "       make bins_install"
	@echo
	@echo
	@echo "For the client/server binary, issue the following command from"
	@echo "the top level directory as root:"
	@echo
	@echo "       make server_bins"
	@echo "       make server_bins_install"
	@echo

#
# The main install is the "rust:" section
#

rust:
	(cd install; $(PERL) mk_files $(OS) $(INSTALLDIR) $(TOPLEVEL) $(LOCALBINDIR))
	(cd install; $(PERL) extract_bin $(OS) $(INSTALLDIR))
	@echo
	@echo "Please check the tmp directory if you want to check"
	@echo "the extracted scripts.  When satisfied, issue"
	@echo
	@echo "         make rust_install"
	@echo
	@echo "to install the files."
	@echo

rust_install:
	# Make the binary
	$(CC) -o tmp/rust tmp/rust.c
	$(INSTALLPROGRAM) -m 755 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/active
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/resolved
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/archived
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/headers
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/mail_archives
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/etc
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/etc/numbers
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/etc/auth
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/etc/dont_make
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/modules
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/modules/XRust
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/pl_lib
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/scripts
	$(INSTALLPROGRAM) -m 700 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/admin
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/bin
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/bin/$(OS)
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/logs
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(INSTALLDIR)/tmp
	$(INSTALLPROGRAM) -m 2770 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/debug
	# Install the RUST modules...
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Lock.pm $(INSTALLDIR)/modules/Lock.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Action.pm $(INSTALLDIR)/modules/Rust_Action.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Admin.pm $(INSTALLDIR)/modules/Rust_Admin.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Data.pm $(INSTALLDIR)/modules/Rust_Data.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Debug.pm $(INSTALLDIR)/modules/Rust_Debug.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Exit.pm $(INSTALLDIR)/modules/Rust_Exit.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Lib.pm $(INSTALLDIR)/modules/Rust_Lib.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Mail.pm $(INSTALLDIR)/modules/Rust_Mail.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/Rust_Query.pm $(INSTALLDIR)/modules/Rust_Query.pm
	# Now do the XRust Modules...
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/XRust/Emulate.pm $(INSTALLDIR)/modules/XRust/Emulate.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/modules/XRust/Mail.pm $(INSTALLDIR)/modules/XRust/Mail.pm
	# Now do the XRust plib files...
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_color.pl $(INSTALLDIR)/pl_lib/xrust_color.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_comment.pl $(INSTALLDIR)/pl_lib/xrust_comment.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_create.pl $(INSTALLDIR)/pl_lib/xrust_create.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_emulate.pl $(INSTALLDIR)/pl_lib/xrust_emulate.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_filter.pl $(INSTALLDIR)/pl_lib/xrust_filter.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_index.pl $(INSTALLDIR)/pl_lib/xrust_index.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_menu.pl $(INSTALLDIR)/pl_lib/xrust_menu.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_request.pl $(INSTALLDIR)/pl_lib/xrust_request.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_merge.pl $(INSTALLDIR)/pl_lib/xrust_merge.pl
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) src/pl_lib/xrust_configure.pl $(INSTALLDIR)/pl_lib/xrust_configure.pl
	# Now install the stuff we extracted...
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/xrust_server.pl $(INSTALLDIR)/scripts/xrust_server.pl
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/action $(INSTALLDIR)/scripts/action
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/query $(INSTALLDIR)/scripts/query
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/archiver $(INSTALLDIR)/scripts/archiver
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/process_mail $(INSTALLDIR)/scripts/process_mail
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(USER_GROUP) tmp/xrust $(INSTALLDIR)/bin/$(OS)/xrust
	$(INSTALLPROGRAM) -m 2755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/rust $(INSTALLDIR)/bin/$(OS)/rust
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) tmp/rust_configs $(INSTALLDIR)/etc/rust_configs
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(USER_GROUP) tmp/Rust_Configs.pm $(INSTALLDIR)/modules/Rust_Configs.pm
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/action
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/query
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/xrust_server
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/action
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/query
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/xrust_server
	# Install administrative scripts now
	$(INSTALLPROGRAM) -m 500 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/r-admin $(INSTALLDIR)/admin/r-admin
	$(INSTALLPROGRAM) -m 500 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/process_mailbox $(INSTALLDIR)/admin/process_mailbox
	$(INSTALLPROGRAM) -m 500 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/req2rust $(INSTALLDIR)/admin/req2rust
	$(INSTALLPROGRAM) -m 500 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/multireq2rust $(INSTALLDIR)/admin/multireq2rust


#
# Install the RUST binary without installing the rest of RUST
#

bins:
	(cd install; $(PERL) extract_bin $(OS) $(INSTALLDIR))
	@echo
	@echo "Please check the tmp directory if you want to check"
	@echo "the extracted C source for compliation.  When satisfied, issue"
	@echo
	@echo "         make bins_install"
	@echo
	@echo "to compile/install the files."
	@echo


bins_install:
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(USER_GROUP) -d $(INSTALLDIR)/bin/$(OS)
	$(CC) -o tmp/rust tmp/rust.c
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(USER_GROUP) tmp/xrust $(INSTALLDIR)/bin/$(OS)/xrust
	$(INSTALLPROGRAM) -m 2755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/rust $(INSTALLDIR)/bin/$(OS)/rust
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/action
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/query
	$(RM) -f $(INSTALLDIR)/bin/$(OS)/xrust_server
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/action
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/query
	$(LN) $(INSTALLDIR)/bin/$(OS)/rust $(INSTALLDIR)/bin/$(OS)/xrust_server

#
# For the server/client
#

server:
	(cd install; $(PERL) mk_files_server $(OS) $(INSTALLDIR) $(SERVERDIR) $(SERVERPORT))
	(cd install; $(PERL) extract_bin_server $(OS) $(SERVERDIR) $(LOCALBINDIR) $(SERVERPORT))
	@echo
	@echo "Please check the tmp directory if you want to check"
	@echo "the extracted C source for compliation.  When satisfied, issue"
	@echo
	@echo "         make server_install"
	@echo
	@echo "to compile/install the files."
	@echo

server_install:
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(SERVERDIR)
	$(INSTALLPROGRAM) -m 755 -o root -g bin -d $(LOCALBINDIR)
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(SERVERDIR)/server
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(SERVERDIR)/client
	$(INSTALLPROGRAM) -m 2750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) -d $(SERVERDIR)/modules
	$(CC) -D$(DEFINES) -o tmp/check-q.bin tmp/check-q.bin.c
	# Install scripts needed for the server
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/user_query $(INSTALLDIR)/scripts/user_query
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/user_query_log $(INSTALLDIR)/scripts/user_query_log
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/server_script $(SERVERDIR)/server/rs_$(SERVERPORT)
	$(INSTALLPROGRAM) -m 750 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/client_script $(SERVERDIR)/client/rc_$(SERVERPORT)
	# Install the server/client perl modules
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Base.pm $(SERVERDIR)/modules/Base.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Client_Server.pm $(SERVERDIR)/modules/Client_Server.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Debug.pm $(SERVERDIR)/modules/Debug.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Error.pm $(SERVERDIR)/modules/Error.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Exit.pm $(SERVERDIR)/modules/Exit.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Log.pm $(SERVERDIR)/modules/Log.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Parse.pm $(SERVERDIR)/modules/Parse.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Print.pm $(SERVERDIR)/modules/Print.pm
	$(INSTALLPROGRAM) -m 640 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) src/server/modules/Signal.pm $(SERVERDIR)/modules/Signal.pm
	# Now do the binaries
	$(INSTALLPROGRAM) -m 2755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/check-q.bin $(LOCALBINDIR)/check-q.bin
	$(INSTALLPROGRAM) -m 755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/check-q $(LOCALBINDIR)/check-q

#
# Install the RUST user interface binary without installing the rest of the server/client
#

server_bins:
	(cd install; $(PERL) extract_bin_server $(OS) $(SERVERDIR) $(LOCALBINDIR) $(SERVERRPORT))
	@echo
	@echo "Please check the tmp directory if you want to check"
	@echo "the extracted binaries for compliation.  When satisfied, issue"
	@echo
	@echo "         make server_bins_install"
	@echo
	@echo "to compile/install the files."
	@echo

server_bins_install:
	$(INSTALLPROGRAM) -m 755 -o root -g bin -d $(LOCALBINDIR)
	$(CC) -D$(DEFINES) -o tmp/check-q.bin tmp/check-q.bin.c
	$(INSTALLPROGRAM) -m 2755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/check-q.bin $(LOCALBINDIR)/check-q.bin
	$(INSTALLPROGRAM) -m 2755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/check-q.bin $(LOCALBINDIR)/check-q.bin
	$(INSTALLPROGRAM) -m 755 -o $(PSEUDO_USER) -g $(PSEUDO_GROUP) tmp/check-q $(LOCALBINDIR)/check-q

#
# Clean up after ourselves
#

clean:
	$(RM) tmp/*

#EOF
