# -*- Perl -*-
#
# Copyright (C) 1996 Craig Ruefenacht <ruefenac@cs.utah.edu> and the
#                    University of Utah Computer Science Department
#
# $Id: Rust_Install.pm,v 1.15 1997/09/20 19:43:17 ruefenac Exp $
#
# This is part of RUST-1.0 Beta 6 patchlevel 2
#
# Abstract: This library contains functions to create a hash for
#           installation of RUST.
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with the source distribution of Inquire, in the license
# directory. If you don't have a copy of it, write to: 
#
# Free Software Foundation, Inc.
# 675 Mass Ave
# Cambridge, MA 02139, USA.# Make links
#
# How this file works
#
#      This file contains all the install options of RUST.
#      To modify/change configuration variables, go through the
#      "get_install" subroutine and change whatever you are looking
#      for. There are comments throughout the subroutine that
#      explains what config variables do what, so read carefully.

{
package Rust_Install;

require Exporter;
@ISA = qw(Exporter);
@EXPORT =
    (
     # name                       brief description
     # --------------------------------------------------------     
     'get_install',		# Create a hash table of install vars
     );
 
#-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*
sub get_install {
    #
    # Type: Can be called by external scripts
    #
    # Abstract: Create a new "class" definition to hold install config
    #           information.

    $install = {};

    # ======================================================
    # MACHINE SETUP

    # mail_server_machine is your main mail server.  It may
    # be different than the machine that you are using for 
    # the RUST System.  For example, our main mail machine
    # is cs.utah.edu, but RUST does not reside on that machine.
    # This value is NOT returned as a global var.  This machine
    # should be the one that all (or most) RUST queue email
    # addresses point to.  It is used later on to construct
    # the email address of each RUST Queue.

    $mail_server_machine = 'cs.utah.edu';
    $install->{'install_mail_server_machine'} = $mail_server_machine;
    
    # rust_server_machine is the machine on which you are
    # installing RUST.  It can be the same as mail_server_machine,
    # or it can be different.

    $install->{'install_rust_server_machine'} = 'emily.cs.utah.edu';

    # smtp_server is the machine in which you want to use for
    # smpt connections.  I would suggest using the machine
    # on which RUST physically resides.

    $install->{'install_smtp_server'} = 'emily.cs.utah.edu';

    # ======================================================
    # PROGRAM PATH SETUP
    #
    # path_to_perl is the path to where the perl exacutable
    # is.  It needs to be at least perl5.000.  I have only tested
    # it on perl5.002 though.  If you don't have perl5.002 and
    # have problems, see about installing perl5.002 and see
    # if it fixes the problem.  It will not work with anything
    # below version 5.000.

    $install->{'install_path_to_perl'} = '/usr/local/bin/perl';

    # path_to_sendmail is the path to your sendmail exacutable.
    # This is only used in the GUI mail window.  Everything else
    # in RUST uses the MailTool perl modules. 
    #
    # DO NOT INCLUDE ANY FLAGS HERE.

    $install->{'install_path_to_sendmail'} = '/usr/lib/sendmail';

    # compress_util is the name of a compression program you want RUST
    # to use to compress the mail archives generated with the
    # mail_archiving option.  At the beginning of each month,
    # RUST will take the current archive file and compress it and
    # then start a new one.  The compress program can be anything
    # from "compress" to "gzip" to just plain old "zip"
    #
    # This program will only be run by the mailer UID, and it will not
    # be used when running SETGID.

    $install->{'install_path_to_compress_util'} = '/usr/local/gnu/bin/gzip';

    # mkdir_prog is the path and name of the binary that can be
    # used to make directories when RUST needs them made.  I
    # have this config here because it will be used in setgid
    # circumstances on occasion, so it needs to be untainted,
    # and I can't just give the setgid perl a "path" to search
    # for it.  It can be either GNU mkdir or just the standard
    # vendor-shipped mkdir.
    #
    # NOTE: This will be used on more machines than just the
    # mail server.  If mkdir is not in the same place on all
    # machines, this is a potential breaking point of RUST.
    # The mkdir prog should most always be found in /bin/

    $install->{'install_path_to_mkdir'} = '/usr/local/gnu/bin/mkdir';

    # chmod_prog is the path and name of the binary that can be
    # used to set UNIX permissions on files when RUST creates
    # directories inside the database directories.  I set
    # UNIX permissions with umask numbers, so whatever you have
    # here should work with umask numbers.  I have this
    # config here because it will be used in setgid
    # circumstances on occasion, so it needs to be untainted,
    # and I can't just give the setgid perl a "path" to search
    # for it.  It can be either GNU chmod or just the standard
    # vendor-shipped chmod.
    #
    # NOTE: This will be used on more machines than just the
    # mail server.  If chmod is not in the same place on all
    # machines, this is a potential breaking point of RUST.
    # The chmod prog should most always be found in /bin/

    $install->{'install_path_to_chmod'} = '/usr/local/gnu/bin/chmod';

    # ======================================================
    # ADMIN AND RUST SERVER EMAIL SETUP

    # admin returns a valid email address to some human who is
    # kinda over the RUST System.  This email address is used by
    # the RUST system to let someone know when problems are found.
    # This is a REQUIRED config, and it needs to go to a human being.

    $install->{'install_admin'} = "rust-admin\@$mail_server_machine";

    # mail_server returns a valid email address to be used for the
    # RUST mail server.  THIS IS NOT IMPLEMENTED YET.

    $install->{'install_mail_server'} = "rustserve\@$mail_server_machine";

    # ======================================================
    # LOGS AND DEBUG SETUP
    # 
    # The following variables are used to configure logging
    # and debugging for RUST.

    # do_logging returns 1 if you want to do logging, 0 otherwise.
    # I strongly recommend to do logging. 

    $install->{'install_do_logging'} = 1;

    # do_debugging has three values you can return.  If it returns
    # 0, no debugging will be done.  If it returns 1, some debugging
    # will be done.  If it returns 2, then debugging will be
    # extensive.  I suggest you leave it at 1 unless you are having
    # big problems.   If things are doing great, make it 0.

    $install->{'install_do_debugging'} = 1;

    # ======================================================
    # UNIX PERMISSIONS SETUP
    #
    # The following variables are used for unix permissions.

    # pseudo_user returns the pseudo user.  All RUST files
    # will be owned by this user.  It *should not* be someone's
    # account.  It needs to be a pseudo user.  You need to create
    # one if you haven't already.  The pseudo user needs to have
    # a valid login (ie people can log in as the pseudo user if
    # needed)

    $install->{'install_pseudo_user'} = 'rustsys';

    # group_name returns the group for which all RUST files will
    # be in.  This should be a group that only the pseudo user and
    # the mailer UID (usually UID 7) can be in.  No humans should
    # be in this group.

    $install->{'install_group_name'} = 'rustsys';

    # user_group returns the group for which all people on RUST queues
    # can belong to.  This needs to include all humans who want to be
    # able to do anything to RUST queues (besides use the user interfaces).
    # It must be different from group_name

    $install->{'install_user_group'} = 'rust';

    # ======================================================
    # REQ AND MULTI_REQ -> RUST CONVERSION

    # The following configs deals with converting req-1.2.x and
    # multi-req-1.x database files over to RUST.  There are only
    # two configs here. 

    # path_to_req_configs is the full path to multi-req-1.x
    # lib directory, which *should* contain req-configs.  This
    # is only if you are converting multi-req database files.

    $install->{'install_path_to_req_configs'} = '/home/assist/req/lib';

    # req_perl_tagline is the tagline you used in REQ.  See the
    # "req-operation" script, and look in the function
    # "sub extract_request_number".  The perl_tagline you should
    # use for req_perl_tagline is inside the extract_request_number function
    # on this line:
    #
    #       if($line =~ /@{PERL_TAGLINE}/) {
    #
    # This is only if you are converting req-1.2.x database files.
    
    $install->{'install_req_perl_tagline'} = "\\[opers\\s*#(-?\\d+)\\]";

    # ======================================================
    # MISCALLANEOUS SETUP
    #
    # Miscallaneous configuration variables

    # When RUST creates a new request, it assigns it a "ticket"
    # number.  From that point on, the way that RUST keeps track
    # of the request is via a "tag", which is inserted into the
    # subject line of outgoing email.  The tags, which are generated
    # further down in this file, have the format
    #
    #            [$queue #<request_num>]
    #
    # where $queue is the name of the RUST queue, and <request_num>
    # is the assigned request number.  This tag *MUST* be in the
    # subject line of all mail regarding a specific request.
    
    # tag_prefix is a string which you want prepended to the
    # $queue part of the "tag", as described above.  For example,
    # if I had a RUST queue named "help", and I specified
    # "U of U" as the tag_prefix, the "tag" would become
    #
    #           [U of U help #<request_num>]
    #
    # If you don't want a prefix, just make tag_prefix = ""
    # The tag_prefix will be added to *ALL* queues which are
    # on this RUST System. 

    $install->{'install_tag_prefix'} = "";

    # install_local_doman is a list of domains which is
    # considered to be "local" to where you are installing
    # RUST.  For example, here at the University of Utah,
    # the local domains are cs.utah.edu and eng.utah.edu.
    # This is used to determine whether the user who sends
    # email to RUST can run the RUST supplied user interfaces
    # or not.

    $install->{'install_local_domain'} = "cs.utah.edu,eng.utah.edu";

    # ======================================================
    # RUST SERVER/CLIENT SETUP
    #
    # The server/client provides a framework for user interfaces.
    # Since the RUST Mail System files are protected, users can't
    # just go and look at the database.  The server/client is meant
    # to get around this problem.
    #
    # The reason why all this stuff isn't just kept in the Rust_Configs.pm
    # is because the Rust_Configs.pm module file would then need to be
    # world readable.  The server/client, once it is installed
    # isn't trivial to change.  You'd have to edit the actual
    # scripts if you want to change port numbers down the road.

    # server_machine is the fully qualified name of the machine in which
    # the RUST Mail System servers will be running.  It should include
    # machine name and internet domain name.  This should be the same
    # machine which you are using for the mail server for RUST.

    $install->{'install_server_machine'} = 'emily.cs.utah.edu';

    return $install;
}
};

1

#EOF
