# -*- Perl -*-
#
# X-Rust Filter Definitions and Subroutines
#
# $Id: xrust_filter.pl,v 1.4 1997/04/16 20:18:16 ruefenac Exp $

use strict;
use vars qw(%FILTER $globals %COLORS @caller_queues %FONTS);

%FILTER = (
	   'user'       => '',
	   'owner'      => '',
	   'unowned'    => 1,
	   'category'   => 'both',
	   'status'     => 'all',
	   'type'       => 'active',
	   'priority'   => 'all',
	   'queue_name' => 'all'
	  );

sub create_filter_window {

    my $FILTER_WINDOW = MainWindow->new;
    $FILTER_WINDOW->title("X-Rust Filter Panel");
    push(@{$COLORS{'Default'}->{'widgets'}},$FILTER_WINDOW);

    $FILTER_WINDOW->resizable(0,0);
    
    my $panel = &create_filter_panel($FILTER_WINDOW);
    $panel->pack(-side => 'top', -fill => 'x', -expand => 1);
    
    # ***** Buttons *****
    
    my $button_frame = $FILTER_WINDOW->Frame;
    $button_frame->pack( -side => 'top', -fill => 'x', -expand => 1);
    push(@{$COLORS{'Default'}->{'widgets'}},$button_frame);
    
    my $button_query = $button_frame->Button(
					     -text => "Rescan",
					     -font => $FONTS{'BUTTON_FONT'},
					     -command => \&do_query
					    );
    $button_query->pack( -side => 'left', -fill => 'x' , -expand => 1);
    push(@{$COLORS{'Buttons'}->{'widgets'}},$button_query);

    my $button_close = $button_frame->Button(
					     -text => "Close",
					     -font => $FONTS{'BUTTON_FONT'},
					     -command => sub { 
						 $FILTER_WINDOW->destroy;
					     }
					    );
    $button_close->pack( -side => 'left', -fill => 'x', -expand => 1);
    push(@{$COLORS{'Buttons'}->{'widgets'}},$button_close);
    
    $FILTER_WINDOW->OnDestroy([\&delete_from_color,
			      $FILTER_WINDOW,
			      $FILTER_WINDOW->Descendants]);
    my $style;
    foreach $style (keys %COLORS) {
	&colorize_widgets($style);
    }

}

sub delete_from_color {
    my($l,$a,$b,$c,@wid);
    my @kk = @_;

    foreach $c (keys %COLORS) {
	foreach $l (keys %{$COLORS{$c}}) {
	    if ($l eq 'widgets') {
		print XRUSTRC"\$COLORS{'$c'}->{'$l'} = '$COLORS{$c}->{$l}';\n";
		@wid = @{$COLORS{$c}->{$l}};
		foreach $a (0..$#wid) {
		    foreach $b (0..$#kk) {
			#print "$wid[$a] =? $kk[$b]\n";
			if (@wid[$a] eq @_[$b]) {
			    #print "MATCH: $a -- @_[$b]\n";
			    $COLORS{$c}->{$l}->[$a] = "";
			}
		    }
		}
	    }
	}
    }
}
sub create_filter_panel {
    
    my $MW = shift;

    my ($each,$count,$radial);

    my $topframe = $MW->Frame;
    push(@{$COLORS{'Default'}->{'widgets'}},$topframe);

    my $column1 = $topframe->Frame;
    my $column2 = $topframe->Frame;

    my @column_packing = (-side => 'left', -fill => 'both', -pady => 5, -padx => 5);
    $column1->pack(@column_packing);
    $column2->pack(@column_packing);
    push(@{$COLORS{'Default'}->{'widgets'}},$column1);
    push(@{$COLORS{'Default'}->{'widgets'}},$column2);

    my @frame_packing = (
			 -side => 'top',
			 -fill => 'x',
			 -pady => 1
			 );

    # **** User ****

    my $user_frame = $column1->Frame;
    $user_frame->pack(@frame_packing);

    &create_filter_label($user_frame,"User");
    my $user_entry = $user_frame->Entry(
					-relief => 'sunken',
					-width  => 10,
					-textvariable => \$FILTER{'user'},
					);
    $user_entry->pack(-side => 'top', -fill => 'x');
    push(@{$COLORS{'Entry'}->{'widgets'}},$user_entry);

    $user_entry->bind('<Return>',\&do_query);

    # **** Owner ****

    my $owner_frame = $column1->Frame;
    $owner_frame->pack(@frame_packing);

    &create_filter_label($owner_frame,"Owner");
    my $owner_entry = $owner_frame->Entry(
					  -relief => 'sunken',
					  -width  => 10,
					  -textvariable => \$FILTER{'owner'},
					  );
    $owner_entry->pack(-side => 'top', -fill => 'x');
    push(@{$COLORS{'Entry'}->{'widgets'}},$owner_entry);

    $owner_entry->bind('<Return>',\&do_query);

    my $unowned_frame = $column1->Frame;
    $unowned_frame->pack(@frame_packing);

    &create_filter_label($owner_frame,"Show Unowned?");
    my $radial = $unowned_frame->Radiobutton(
					     -text      => "yes",
					     -font      => $FONTS{'BUTTON_FONT'},
					     -variable  => \$FILTER{'unowned'},
					     -value     => 1,
					     );
    $radial->pack(-side => 'top', -anchor => 'w');
    push(@{$COLORS{'Radial'}->{'widgets'}},$radial);

    $radial = $unowned_frame->Radiobutton(
					  -text      => "no",
					  -font      => $FONTS{'BUTTON_FONT'},
					  -variable  => \$FILTER{'unowned'},
					  -value     => 0,
					  );
    $radial->pack(-side => 'top', -anchor => 'w');
    push(@{$COLORS{'Radial'}->{'widgets'}},$radial);

    # **** Queue *****

    my $queue_frame = $column1->Frame;
    $queue_frame->pack(@frame_packing);
    push(@{$COLORS{'Radial'}->{'widgets'}},$queue_frame);

    &create_filter_label($queue_frame,"Queue");
    my $radial = $queue_frame->Radiobutton(
					   -text     => "all",
					   -font     => $FONTS{'BUTTON_FONT'},
					   -variable => \$FILTER{'queue_name'},
					   -value    => "all",
					   );
    $radial->pack(-side => 'top', -anchor => 'w');
    push(@{$COLORS{'Radial'}->{'widgets'}},$radial);

    $count = 0;
    foreach $each (split(':',$globals->{"alias_name"})) {
	if ($caller_queues[$count]) {
	    $radial = $queue_frame->Radiobutton(
						-text     => "$each",
						-font     => $FONTS{'BUTTON_FONT'},
						-variable => \$FILTER{'queue_name'},
						-value    => $each,
						);
	    $radial->pack(-side => 'top', -anchor => 'w');
	    push(@{$COLORS{'Radial'}->{'widgets'}},$radial);
	}
	$count++;
    }

    # **** Category *****

    my $category_frame = $column1->Frame;
    $category_frame->pack(@frame_packing);
    push(@{$COLORS{'Radial'}->{'widgets'}},$category_frame);

    &create_filter_label($category_frame,"Category");
    foreach $each ("user","work","both") {
	$radial = $category_frame->Radiobutton(
					       -text     => "$each",
					       -font     => $FONTS{'BUTTON_FONT'},
					       -variable => \$FILTER{'category'},
					       -value    => $each,
					       );
	$radial->pack(-side => 'top', -anchor => 'w');
	push(@{$COLORS{'Radial'}->{'widgets'}},$radial);
    }

    # **** Status ****

    my $status_frame = $column2->Frame;
    $status_frame->pack(@frame_packing);
    push(@{$COLORS{'Radial'}->{'widgets'}},$status_frame);

    &create_filter_label($status_frame,"Status");
    foreach $each ("all",split(':',$globals->{"valid_status"})) {
	$radial = $status_frame->Radiobutton(
					     -text     => "$each",
					     -font     => $FONTS{'BUTTON_FONT'},
					     -variable => \$FILTER{'status'},
					     -value    => $each,
					     );
	$radial->pack(-side => 'top', -anchor => 'w');
	push(@{$COLORS{'Radial'}->{'widgets'}},$radial);
    }

    # **** Priority ****

    my $priority_frame = $column2->Frame;
    $priority_frame->pack(@frame_packing);
    push(@{$COLORS{'Radial'}->{'widgets'}},$priority_frame);

    &create_filter_label($priority_frame,"Priority");
    foreach $each ("all","high","normal","low") {
	$radial = $priority_frame->Radiobutton(
					       -text     => "$each",
					       -font     => $FONTS{'BUTTON_FONT'},
					       -variable => \$FILTER{'priority'},
					       -value    => $each,
					       );
	$radial->pack(-side => 'top', -anchor => 'w');
	push(@{$COLORS{'Radial'}->{'widgets'}},$radial);
    }

    # **** Queue Type ****

    my $queue_type_frame = $column2->Frame;
    $queue_type_frame->pack(@frame_packing);
    push(@{$COLORS{'Radial'}->{'widgets'}},$queue_type_frame);

    &create_filter_label($queue_type_frame,"Queue Type");
    foreach $each ("active","resolved","archived") {
	$radial = $queue_type_frame->Radiobutton(
						 -text     => "$each",
						 -font     => $FONTS{'BUTTON_FONT'},
						 -variable => \$FILTER{'type'},
						 -value    => $each,
						 );
	$radial->pack(-side => 'top', -anchor => 'w');
	push(@{$COLORS{'Radial'}->{'widgets'}},$radial);
    }

    return $topframe;
}

sub create_filter_label {
    my $frame = shift;
    my $text = shift;
    
    my $label = $frame->Label(
			      -text => "$text",
			      -font => $FONTS{'TEXT_FONT'},
			      -relief => 'ridge'
			      );

    $label->pack(
		 -side => 'top',
		 -fill => 'x'
		 );
    push(@{$COLORS{'Labels'}->{'widgets'}},$label);
    return $label;
}



1;
