/* rust.c

Copyright (C) 1996 Craig Ruefenacht <ruefenac@cs.utah.edu> and the
                   University of Utah Computer Science Department

$Id: rust.c,v 1.12 1997/09/20 19:43:02 ruefenac Exp $

This is part of RUST-1.0 Beta 6 patchlevel 2

Abstract: This C program is a simple wrapper around the RUST
          System scripts.  It is a setgid wrapper.  It checks
          to see if the caller is in at least one RUST queue,
          and if so, then it calls the actual RUST System scripts,
          which are not directly accessable by the caller.

          I didn't want to have any binaries in RUST, let alone
          a setgid wrapper, but it was the only way to deal with
          permissions if several RUST queues exist.  This will be
          more beneficial than a problem down the road.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the source distribution of RUST, in the license
directory. If you don't have a copy of it, write to:

Free Software Foundation, Inc.
675 Mass Ave
Cambridge, MA 02139, USA.

This C program gets "processed" through a perl script I wrote.
you shouldn't have to edit anything in this file, unless you want
to add other user interfaces.  To add interface scripts, extend
the progmap[] struct.  Make sure that the { 0, 0 } entry is last. */

#include <pwd.h>
#include <stdio.h>
#include <string.h>

#define AUTH_FILE	"{install_top_level}/etc/RUST.names"
#define NAME_MAX	40

static struct progmap {
    char *name;
    char *prog;
} progmap[] = {
    { "action", "{install_action_script}" },

    { "query", "{install_query_script}" },

    { "xrust_server", "{install_xrust_server.pl}" },
    
    { 0, 0 }
};

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
static int
userok()
{
    struct passwd *pw;
    FILE *auth_file;
    char username[NAME_MAX];

    if ((pw = getpwuid(getuid())) == NULL)
	fprintf(stderr, "no passwd entry for %d\n", getuid()), exit(1);

    if ((auth_file = fopen(AUTH_FILE, "r")) == NULL)
	fprintf(stderr, "cannot open %s\n", AUTH_FILE), exit(1);

    while (fgets(username, NAME_MAX, auth_file) != NULL) {
	username[strlen(username) - 1] = '\0';
	if (strcmp(username, pw->pw_name) == 0)
	    return 1;
    }
    return 0;
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
static void
runprog(name, argv)
    char *name;
    char *argv[];
{
    struct progmap *pm;
    char *name_base, *p;

    /* The below loop is designed to get just the basename of
       the program.  There is a basename() in libgen.h on some
       systems, but on others, it is elsewhere.  This is a patched
       version to what I wrote.  This is shorter than mine, and
       works. */

    p = strrchr( argv[0], '/' );
    if ( p && *++p )
	name_base = p;
    else
	name_base = argv[0];

    for (pm = progmap; pm->name != NULL; pm++)
        if (strcmp(pm->name, name_base) == 0) {
	    argv[0] = pm->prog;

	    execv(pm->prog, argv);
	    perror("exec");
	    exit(1);
	}
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
void
main(argc, argv)
    int argc;
    char *argv[];
{

    if (! userok())
	fprintf(stderr, "sorry, you can't run this\n"), exit(1);

    runprog(argv[0], argv);
    /* Shouldn't get here.  */
    fprintf(stderr, "no matching program for %s\n", argv[0]);
}

