/* check-q.bin.c

Copyright (C) 1996 Craig Ruefenacht <ruefenac@cs.utah.edu> and the
                   University of Utah Computer Science Department

$Id: check-q.bin.c,v 1.2 1997/09/20 19:44:16 ruefenac Exp $

This is part of RUST-1.0 Beta 2 patchlevel 2

Abstract: This C program is a simple wrapper around the RUST
          System scripts.  It is a setgid wrapper.  This does
	  no checking of the caller.  All it does is get the
	  caller's associated login name, and then passes
	  that, along with any args given to this program,
	  to the "client", which then connects to the "server"
	  via tcp/ip, and gets info from the server.  The
	  reason why this is setgid and binary is so that
	  users can't easily "spoof" requests to the client/server.
	  
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with the source distribution of RUST, in the license
directory. If you don't have a copy of it, write to:

Free Software Foundation, Inc.
675 Mass Ave
Cambridge, MA 02139, USA.

This C program gets "processed" through a perl script I wrote.
you shouldn't have to edit anything in this file, unless you want
to add other user interfaces.  */

#include <pwd.h>
#include <stdio.h>

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
void*
malloc_or_die(len)
    int len;
{
        void *p;

	if ((p = (void *)malloc(len)) == NULL) {
	            fprintf(stderr, "no more mem\n");
		            exit(1);
	}
	    return p;
}

/*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*-*/
void
main(argc, argv)
    int argc;
    char *argv[];
{
    struct passwd *pw;
    char **new_argv;
    char **p_new_arg;
    int i;

    /* Don't know if this will work on a NIS+ machine, since the passwd
       stuff is done a little bit differently.  It is important to be
       able to get the user's login name here, so that we know who the
       user is.  Can't pass it in as an argument, because then any user
       could put anything they wanted to. */
    
    if ((pw = getpwuid(getuid())) == NULL)
	fprintf(stderr, "no passwd entry for %d\n", getuid()), exit(1);

    /* Going to add two args to the list, so allocate room for all old
       args, plus the two new ones */

    new_argv = (char **)malloc_or_die(sizeof(char *) * (argc + 3));
    p_new_arg = new_argv;
    
    /* The first arg (new_argv[0]) needs to be the name of the program
       it will be calling futher down. */
    
    *p_new_arg = (char *)malloc_or_die(11);
    if (argc == 2) {
	if ((strcmp(argv[1], "--gui") == 0) ||
	    (strcmp(argv[1], "-gui") == 0)) {
	    *p_new_arg = (char *)malloc_or_die(strlen("{xcheck-q_script}") + 1);
	    strcpy(*p_new_arg, "{xcheck-q_script}");
	}
    } else {
	*p_new_arg = (char *)malloc_or_die(strlen("{client_script}") + 1);
	strcpy(*p_new_arg, "{client_script}");
    }
    p_new_arg++;
    
    *p_new_arg = (char *)malloc_or_die(6);
    strcpy(*p_new_arg, "--tcp");
    p_new_arg++;

    *p_new_arg = (char *)malloc_or_die(2);

#ifdef TCP_2    
    strcpy(*p_new_arg, "2");
#else
    strcpy(*p_new_arg, "1");
#endif

    p_new_arg++;


    if(argc > 2) {
	for(i=1;i<argc;i++) {
            *p_new_arg = (char *)malloc_or_die(strlen(argv[i]) + 1);
            strcpy(*p_new_arg, argv[i]);
            p_new_arg++;
        }
    } else if (argc == 2) {
        *p_new_arg = (char *)malloc_or_die(strlen(argv[1] + 1));
	if ((strcmp(argv[1], "--gui") == 0) ||
	    (strcmp(argv[1], "-gui") == 0)) {
	    p_new_arg++;
	    *p_new_arg = NULL;
	    printf("Please be patient while the GUI is starting up...\n"); 
	    execv("{xcheck-q_script}", new_argv);
	    perror("exec");
	    exit(1);
	}
        strcpy(*p_new_arg, argv[1]);
        p_new_arg++;
    }

    /* Add the two args onto the end.  These two args are the main
       reason why this is a C program, to hide this detail from the user.
       The reason being, if you know what args to give to the client,
       you can make the server give you any info on any request.

       As added security, this is a setgid script, so that the actual
       client script isn't accessible, except via this binary.  It
       shouldn't be too big of a security problem if a user found a way
       to bypass this, since the client/server stuff only gives info out,
       without writing to any files (except a usage logfile) */
    
    *p_new_arg = (char *)malloc_or_die(strlen("--realuser") + 1);
    strcpy(*p_new_arg, "--realuser");
    p_new_arg++;
    *p_new_arg = (char *)malloc_or_die(strlen(pw->pw_name) + 1);
    strcpy(*p_new_arg, pw->pw_name);
    p_new_arg++;
    *p_new_arg = NULL;
    
    /* Now do the actual call to the client, which will in turn connect
       to the server, and print out information */

    printf("Please be patient while I query the RUST System queues...\n");
    execv("{client_script}", new_argv);
    perror("exec");
    exit(1);

}
