# package Server;
#
# -*- Perl -*-
#
# Copyright (C) 1996 Craig Ruefenacht <ruefenac@cs.utah.edu>,
#                    Jason Lauman <lauman@cs.utah.edu> and the
#                    University of Utah Computer Science Department
#
# $Id: Client_Server.pm,v 1.5 1996/09/17 21:41:48 ruefenac Exp $
#
# This is part of rust 1.0 Beta 1
#
# Abstract: Client_Server package for check-q server
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with the source distribution of Inquire, in the license
# directory. If you don't have a copy of it, write to:
#
# Free Software Foundation, Inc.
# 675 Mass Ave
# Cambridge, MA 02139, USA.

@functions = ('Exit','Debug','Error');
require Base;
	
%CLIENT = (
	'PORT',			'',
	'PROTOCOL',	'',
	'SOCKET',		'',
	);

%SERVER = (
	'PORT',			'',
	'PROTOCOL',	'',
	'DUMMY',		'',
	'SOCKET',		'',
	);

sub Server::Init {
	my($port,$protocol, $tcp_num) = @_;
	my($AF_INET,$sockaddr,$SOCK_STREAM);
	my($TCP,$UDP,$name,$aliases,$proto,$this);

	if ($tcp_num == -1) {	

	    ### SOCK_STREAM IS 2 ON SOLARIS/IRIX. 1 MOST EVERYWHERE ELSE ### 

	    if(( `uname -sr` =~ /^SunOS\s+5/ ) ||
	       ( `uname -sr` =~ /^IRIX/ )) { 
		$TCP = 2;
		$UDP = 1;
	    } else {
		$TCP = 1;
		$UDP = 2;
	    }
	} else {

	    ### SOCK_STREAM IS 2 ON SOLARIS/IRIX. 1 MOST EVERYWHERE ELSE ### 
	    
	    if ($tcp_num == 2) {
		$TCP = 2;
		$UDP = 1;
	    } else {
		$TCP = 1;
		$UDP = 2;
	    }
	}

	if( $protocol =~ /tcp/i ) { 
#		$SERVER{'DUMMY'} = "SERVER_DUMMY_SOCKET";
#		$SERVER{'SOCKET'} = "SERVER_NEW_SOCKET";
		$SERVER{'DUMMY'} = "SDS";
		$SERVER{'SOCKET'} = "SNS";
		$SOCK_STREAM = $TCP; 
	}
	elsif( $protocol =~ /udp/i ) { 
		$SERVER{'DUMMY'} = "SERVER_SOCKET";
		$SERVER{'SOCKET'} = "SERVER_SOCKET";
		$SOCK_STREAM = $UDP; 
	}
	else { &$Exit("Protocol $protocol is not supported");	}
	$SERVER{'PROTOCOL'} = $protocol;

	($name,$aliases,$proto) = getprotobyname($protocol);
	( $port !~ /^\d+$/) && ( ($name,$aliases,$port) = getservbyport($port,$protocol) ); 

	$AF_INET = 2;
  $sockaddr = 'S n a4 x8';
	$this = pack($sockaddr, $AF_INET, $port, "\0\0\0\0");

	socket($SERVER{'DUMMY'}, $AF_INET, $SOCK_STREAM, $proto) || &$Exit("socket: $!");
	bind($SERVER{'DUMMY'},$this) || &$Exit("bind: $!");
	( $protocol =~ /tcp/i ) && ( listen($SERVER{'DUMMY'},5) || &$Exit("listen: $!") );

	select($SERVER{'DUMMY'}); $| = 1; select(STDOUT);
	select($SERVER{'SOCKET'}); $| = 1; select(STDOUT);

	return 1;
}

sub Server::Accept {
	my($addr,$sockaddr,$af,$port,$inetaddr,@inetaddr,$child);
	if( $SERVER{'PROTOCOL'} =~ /udp/i ) { return 0; }
	$sockaddr = 'S n a4 x8';
	#&$Print('LOG',"Listening for connection...\n");
	print("Listening for connection...\n");
	($addr = accept($SERVER{'SOCKET'},$SERVER{'DUMMY'}));
	if( $addr ) {
    #&$Print('LOG',"accept ok\n");
    print("accept ok\n");
    ($af,$port,$inetaddr) = unpack($sockaddr,$addr);
    @inetaddr = unpack('C4',$inetaddr);
    #&$Print('LOG',"connection: $af $port @inetaddr\n");
    print("connection: $af $port @inetaddr\n");
		if(($child = fork()) == 0 ) {	return 0;	}
	}
	else { 
		return -1; 
	}
	close($SERVER{'SOCKET'});
	return $child;
}

sub Client::Init {
	my($server,$port,$protocol, $tcp_num) = @_;
	my($AF_INET,$sockaddr,$SOCK_STREAM);
	my($TCP,$UDP,,$hostname,$name,$alias,$proto);
	my($this,$that,$thisaddr,$thataddr);

	if ($tcp_num == -1) {	

	    ### SOCK_STREAM IS 2 ON SOLARIS/IRIX. 1 MOST EVERYWHERE ELSE ### 

	    if(( `uname -sr` =~ /^SunOS\s+5/ ) ||
	       ( `uname -sr` =~ /^IRIX/ )) { 
		$TCP = 2;
		$UDP = 1;
	    } else {
		$TCP = 1;
		$UDP = 2;
	    }
	} else {

	    ### SOCK_STREAM IS 2 ON SOLARIS/IRIX. 1 MOST EVERYWHERE ELSE ### 
	    
	    if ($tcp_num == 2) {
		$TCP = 2;
		$UDP = 1;
	    } else {
		$TCP = 1;
		$UDP = 2;
	    }
	}

	if( $protocol =~ /tcp/i ) { 
		$CLIENT{'SOCKET'} = "CLIENT_SOCKET";
		$SOCK_STREAM = $TCP; 
	}
	elsif( $protocol =~ /udp/i ) { 
		$CLIENT{'SOCKET'} = "CLIENT_SOCKET";
		$SOCK_STREAM = $UDP; 
	}
	else { &$Exit("Protocol $protocol is not supported");	}
	$CLIENT{'PROTOCOL'} = $protocol;

	($name,$aliases,$proto) = getprotobyname($protocol);
	if ( $port !~ /^\d+$/) {		
		($name,$aliases,$port) = getservbyname($port,$protocol)
	}

	if (-x "/bin/hostname") {
            $hostname_path = "/bin/hostname";
            $hostname_path = &untaint_obj($hostname_path);
            $hostname = `$hostname_path`;
            chop $hostname;
        }
        elsif (-x "/usr/ucb/hostname") {
            $hostname_path = "/usr/ucb/hostname";
            $hostname_path = &untaint_obj($hostname_path);
            $hostname = `$hostname_path`;
            chop $hostname;
        }
        elsif (-x "/usr/bin/hostname") {
            $hostname_path = "/usr/bin/hostname";
            $hostname_path = &untaint_obj($hostname_path);
            $hostname = `$hostname_path`;
            chop $hostname;
        }
        elsif (-x "/usr/bsd/hostname") {
            $hostname_path = "/usr/bsd/hostname";
            $hostname_path = &untaint_obj($hostname_path);
            $hostname = `$hostname_path`;
            chop $hostname;
        }

	($name,$aliases,$type,$len,$thisaddr) = gethostbyname($hostname);
	($name,$aliases,$type,$len,$thataddr) = gethostbyname($server);
    
  $AF_INET = 2;
  $sockaddr = 'S n a4 x8';
	$this = pack($sockaddr, $AF_INET, 0, $thisaddr);
	$that = pack($sockaddr, $AF_INET, $port, $thataddr);

	socket($CLIENT{'SOCKET'}, $AF_INET, $SOCK_STREAM, $proto) || &$Exit("socket: $!");
	bind($CLIENT{'SOCKET'},$this) || &$Exit("bind: $!");
  (connect($CLIENT{'SOCKET'},$that)) || &$Exit("connect: server may not be running.\n");

	select($CLIENT{'SOCKET'}); $| = 1; select(STDOUT);
	return 1;
}

sub Client::Test {
	my($server,$port,$protocol) = @_;
	my($AF_INET,$sockaddr,$SOCK_STREAM);
	my($TCP,$UDP,,$hostname,$name,$alias,$proto);
	my($this,$that,$thisaddr,$thataddr);

  ### SOCK_STREAM IS 2 ON SOLARIS. 1 MOST EVERYWHERE ELSE ### 

	# The ugly hack of setting $ENV{PATH} to null is because
	# this runs under a setgid script (sometimes), and you can't
	# have path in a setgid script.  I also had to get the uname
	# info and then "untaint" it, so that perl wouldn't complain.

	$ENV{'PATH'} = "";
	$temp = `/bin/uname -sr`;
	$temp =~ /^(.*)$/;
	$temp = $1;

	if( $temp =~ /^SunOS\s+5/ ) { $TCP = 2; $UDP = 1; }
	else { $TCP = 1; $UDP = 2; }				

	if( $protocol =~ /tcp/i ) { 
		$CLIENT{'SOCKET'} = "CLIENT_SOCKET";
		$SOCK_STREAM = $TCP; 
	}
	elsif( $protocol =~ /udp/i ) { 
		$CLIENT{'SOCKET'} = "CLIENT_SOCKET";
		$SOCK_STREAM = $UDP; 
	}
	else { &$Exit("Protocol $protocol is not supported");	}
	$CLIENT{'PROTOCOL'} = $protocol;

	($name,$aliases,$proto) = getprotobyname($protocol);
	if ( $port !~ /^\d+$/) {		
		($name,$aliases,$port) = getservbyname($port,$protocol)
	}

  chop($hostname = `hostname`);
	($name,$aliases,$type,$len,$thisaddr) = gethostbyname($hostname);
	($name,$aliases,$type,$len,$thataddr) = gethostbyname($server);
    
  $AF_INET = 2;
  $sockaddr = 'S n a4 x8';
	$this = pack($sockaddr, $AF_INET, 0, $thisaddr);
	$that = pack($sockaddr, $AF_INET, $port, $thataddr);

	socket($CLIENT{'SOCKET'}, $AF_INET, $SOCK_STREAM, $proto) || return 1;
	bind($CLIENT{'SOCKET'},$this) || return 1;
  (connect($CLIENT{'SOCKET'},$that)) || return 1;

	select($CLIENT{'SOCKET'}); $| = 1; select(STDOUT);
	return 0;
}


sub Client::Read { return Generic::Read(%CLIENT); }
sub Server::Read { return Generic::Read(%SERVER); }

sub Generic::Read {
	my(%MY) = @_;
	my($string);
	my($socket) = $MY{'SOCKET'};
	sysread($socket,$string,256);
	if( $MY{'PROTOCOL'} =~ /tcp/i ) {
				#&$Print($socket,"ok\n");
				print $socket "ok\n";
	}
	chop($string);	
	return $string;
}

sub Client::Write { 
	my($data) = @_; 
	return Generic::Write(%CLIENT,'DATA',$data); 
}

sub Server::Write { 
	my($data) = @_; 
	return Generic::Write(%SERVER,'DATA',$data); 
}

sub Generic::Write {
	my(%MY) = @_;
	my($data) = $MY{'DATA'};
	my($socket) = $MY{'SOCKET'};
	my($protocol) = $MY{'PROTOCOL'};
	#&$Print($socket,"$data\n");
	print $socket "$data\n";
	if( $protocol =~ /tcp/i ) {
		sysread($socket,$STATUS,64);
		chop($STATUS);
	}
	else { $STATUS = "ok"; }
	if( $STATUS eq "ok" ) {
		return 1;		
	}
	&$Error("Bad status $STATUS\n");
	return 0;
}

sub untaint_obj {
    #
    # Abstract: Untaint whatever is passed in.  This is to
    #           accomidate setgid scripts.  I didn't want to
    #           have to do this, but....
    #
    #           Secure scripts is a good thing, but there are
    #           times when you have to work around it.
 
    my ($tainted_obj) = @_;
 
    $tainted_obj =~ /^(.*)$/;
 
    return $1;
}


1;

